@@ -7,9 +7,9 @@
 #define EVS_DEFAULT_TIMEOUT 90
 #define EVS_MAX_TIMEOUT     432000
 
-#define EVS_CONTEXT_TIMEOUT 0
-#define EVS_CONTEXT_CANCEL  1
-#define EVS_CONTEXT_USER    2
+#define EVS_CONTEXT_TIMEOUT 0U
+#define EVS_CONTEXT_CANCEL  1U
+#define EVS_CONTEXT_USER    2U
 
 typedef enum {
   EVS_TYPE_SUBSCRIPTION = 1
