@@ -305,7 +305,6 @@ void scr_InitCurses(void)
   intrflush(stdscr, FALSE);
   start_color();
   use_default_colors();
-  Curses = TRUE;
 
   ParseColors();
 
@@ -317,6 +316,7 @@ void scr_InitCurses(void)
   inputLine[0] = 0;
   ptr_inputline = inputLine;
 
+  Curses = TRUE;
   return;
 }
 
@@ -769,6 +769,7 @@ void scr_UpdateMainStatus(int forceupdate)
 void scr_DrawMainWindow(unsigned int fullinit)
 {
   int requested_size;
+  gchar *ver, *message;
 
   Log_Win_Height = DEFAULT_LOG_WIN_HEIGHT;
   requested_size = settings_opt_get_int("log_win_height");
@@ -844,8 +845,12 @@ void scr_DrawMainWindow(unsigned int fullinit)
 
   /* Draw/init windows */
 
-  mvwprintw(chatWnd, 0, 0, "Thanks for using mcabber.\n");
+  ver = mcabber_version();
+  message = g_strdup_printf("MCabber version %s.\n", ver);
+  mvwprintw(chatWnd, 0, 0, message);
   mvwprintw(chatWnd, 1, 0, "http://www.lilotux.net/~mikael/mcabber/");
+  g_free(ver);
+  g_free(message);
 
   // Auto-scrolling in log window
   scrollok(logWnd, TRUE);
@@ -1083,8 +1088,6 @@ void scr_DrawRoster(void)
     return;
   }
 
-  name = g_new0(char, Roster_Width);
-
   // Update offset if necessary
   // a) Try to show as many buddylist items as possible
   i = g_list_length(buddylist) - maxy;
@@ -1096,7 +1099,6 @@ void scr_DrawRoster(void)
   i = g_list_position(buddylist, current_buddy);
   if (i == -1) { // This is bad
     scr_LogPrint(LPRINT_NORMAL, "Doh! Can't find current selected buddy!!");
-    g_free(name);
     curs_set(cursor_backup);
     return;
   } else if (i < offset) {
@@ -1105,7 +1107,8 @@ void scr_DrawRoster(void)
     offset = i + 1 - maxy;
   }
 
-  rline = g_new0(char, Roster_Width+1);
+  name = g_new0(char, 4*Roster_Width);
+  rline = g_new0(char, 4*Roster_Width+1);
 
   buddy = buddylist;
   rOffset = offset;
@@ -1165,7 +1168,7 @@ void scr_DrawRoster(void)
     }
 
     if (Roster_Width > 7)
-      strncpy(name, buddy_getname(BUDDATA(buddy)), Roster_Width-7);
+      g_utf8_strncpy(name, buddy_getname(BUDDATA(buddy)), Roster_Width-7);
     else
       name[0] = 0;
 
@@ -1191,7 +1194,7 @@ void scr_DrawRoster(void)
         }
       }
 
-      snprintf(rline, Roster_Width,
+      snprintf(rline, 4*Roster_Width,
                " %c%c%c%c %s", pending, sepleft, status, sepright, name);
     }
 
@@ -2280,7 +2283,7 @@ static void add_keyseq(char *seqstr, guint mkeycode, gint value)
 //  0  if "seq" could match 1 or more known sequences
 // >0  if "seq" matches a key sequence; the mkey code is returned
 //     and *ret is set to the matching keyseq structure.
-static inline guint match_keyseq(int *iseq, keyseq **ret)
+static inline gint match_keyseq(int *iseq, keyseq **ret)
 {
   GSList *ksl;
   keyseq *ksp;
